==> fantacalciobazar_0.2.tar.gz: fantacalciobazar/calcola_punti_giornata.php <==
<?php

################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("head.php");

include("controlla_pass.php");
if ($pass_admin_errata == "NO") {



$voto_tot = "";
$voto_giornale = "";
$punti_tot = "";

# prendo i voti dal file
$voti = file("$giornata/voti.txt");
$num_voti = count($voti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
$dati_voto = explode($separatore_campi_file_voti, $voti[$num1]);
$num_calciatore = $dati_voto[($num_colonna_numcalciatore_file_voti-1)];
$voto_tot[$num_calciatore] = $dati_voto[($num_colonna_vototot_file_voti-1)];
$voto_giornale[$num_calciatore] = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

$sostituisci_P = 0;
$sostituisci_D = 0;
$sostituisci_C = 0;
$sostituisci_A = 0;
$punti_tot[$giocatore] = 0;
$formazione = file("$giornata/formazione_$giocatore");
$num_linee_formazione = count($formazione);

# punteggio dei titolari
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
if (!$formazione[$num2]) break;
if ($formazione[$num2] == "\n") break;
$dati_calciatore = explode(",", $formazione[$num2]);
$num_calciatore = $dati_calciatore[0];
if ($voto_tot[$num_calciatore] == 0 and $voto_giornale[$num_calciatore] == 0) {
$ruolo_calc = $dati_calciatore[2];
$ruolo_calc = ereg_replace("\n","",$ruolo_calc);
$nome_sostituisci = "sostituisci_$ruolo_calc";
$$nome_sostituisci++;
} # fine if ($voto_tot[$num_calciatore] == 0 and...
else {
$nome_calc = $dati_calciatore[1];
$formazione[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",$formazione[$num2]);
$formazione[$num2] = ereg_replace("\n","",$formazione[$num2]);
$formazione[$num2] .= ",".$voto_tot[$num_calciatore]."
";
$punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
} # fine else if ($voto_tot[$num_calciatore] == 0 and...
} # fine for $num2

# punteggio dei panchinari
for ($num2 = ($num2 + 1) ; $num2 < $num_linee_formazione; $num2++) {
if (!$formazione[$num2]) break;
if ($formazione[$num2] == "\n") break;
$dati_calciatore = explode(",", $formazione[$num2]);
$num_calciatore = $dati_calciatore[0];
if ($voto_tot[$num_calciatore] != 0 or $voto_giornale[$num_calciatore] != 0) {
$ruolo_calc = $dati_calciatore[2];
$ruolo_calc = ereg_replace("\n","",$ruolo_calc);
$nome_sostituisci = "sostituisci_$ruolo_calc";
$formazione[$num2] = ereg_replace("\n","",$formazione[$num2]);
$formazione[$num2] .= ",".$voto_tot[$num_calciatore]."
";
if ($$nome_sostituisci >= 1) {
$nome_calc = $dati_calciatore[1];
$formazione[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",$formazione[$num2]);
$punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
$$nome_sostituisci = $$nome_sostituisci - 1;
} # fine if ($$nome_sostituisci >= 1)
} # fine if ($voto_tot[$num_calciatore] != 0 or...
} # fine for $num2

# riscrivo la formazione con i voti
$lock = fopen("adnin.lock","w+");
flock($lock,2);
$fileformazione = fopen("$giornata/formazione_$giocatore","w+");
flock($fileformazione,2);
rewind($fileformazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione ; $num2++) {
fwrite($fileformazione,$formazione[$num2]);
} # fine for $num1
flock($fileformazione,3);
flock($lock,3);
echo "$giocatore: ".$punti_tot[$giocatore]."<br>";
next($pass);
} # fine for $num1


$lock = fopen("adnin.lock","w+");
flock($lock,2);
$filepunteggi = fopen("$giornata/punteggi.txt","w+");
flock($filepunteggi,2);
rewind($filepunteggi);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
fwrite($filepunteggi,"$giocatore,".$punti_tot[$giocatore]."
");
next($pass);
} # fine for $num1
flock($filepunteggi,3);
flock($lock,3);

echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";

} # fine if ($pass_admin_errata == "NO")

include("foot.php");
?>

==> fantacalciobazar_0.2.1.tar.gz: fantacalciobazar/calcola_punti_giornata.php <==
<?php

################################################################################
#    FANTACALCIOBAZAR
#    Copyright (C) 2001 by Marco Maria Francesco De Santis (marcods@gmx.net)
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
################################################################################

include("head.php");

include("controlla_pass.php");
if ($pass_admin_errata == "NO") {



$voto_tot = "";
$voto_giornale = "";
$punti_tot = "";

# prendo i voti dal file
$voti = file("$giornata/voti.txt");
$num_voti = count($voti);
for ($num1 = 0 ; $num1 < $num_voti ; $num1++) {
$dati_voto = explode($separatore_campi_file_voti, $voti[$num1]);
$num_calciatore = $dati_voto[($num_colonna_numcalciatore_file_voti-1)];
$voto_tot[$num_calciatore] = $dati_voto[($num_colonna_vototot_file_voti-1)];
$voto_giornale[$num_calciatore] = $dati_voto[($num_colonna_votogiornale_file_voti-1)];
} # fine for $num1


$num_giocatori=count($pass);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);

$sostituisci_P = 0;
$sostituisci_D = 0;
$sostituisci_C = 0;
$sostituisci_A = 0;
$punti_tot[$giocatore] = 0;
$formazione = file("$giornata/formazione_$giocatore");
$num_linee_formazione = count($formazione);

# punteggio dei titolari
for ($num2 = 0 ; $num2 < $num_linee_formazione; $num2++) {
if (!$formazione[$num2]) break;
if ($formazione[$num2] == "
") break;
$dati_calciatore = explode(",", $formazione[$num2]);
$num_calciatore = $dati_calciatore[0];
if ($voto_tot[$num_calciatore] == 0 and $voto_giornale[$num_calciatore] == 0) {
$ruolo_calc = $dati_calciatore[2];
$ruolo_calc = ereg_replace("
","",$ruolo_calc);
$nome_sostituisci = "sostituisci_$ruolo_calc";
$$nome_sostituisci++;
} # fine if ($voto_tot[$num_calciatore] == 0 and...
else {
$nome_calc = $dati_calciatore[1];
$formazione[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",$formazione[$num2]);
$formazione[$num2] = ereg_replace("
","",$formazione[$num2]);
$formazione[$num2] .= ",".$voto_tot[$num_calciatore]."
";
$punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
} # fine else if ($voto_tot[$num_calciatore] == 0 and...
} # fine for $num2

# punteggio dei panchinari
for ($num2 = ($num2 + 1) ; $num2 < $num_linee_formazione; $num2++) {
if (!$formazione[$num2]) break;
if ($formazione[$num2] == "
") break;
$dati_calciatore = explode(",", $formazione[$num2]);
$num_calciatore = $dati_calciatore[0];
if ($voto_tot[$num_calciatore] != 0 or $voto_giornale[$num_calciatore] != 0) {
$ruolo_calc = $dati_calciatore[2];
$ruolo_calc = ereg_replace("
","",$ruolo_calc);
$nome_sostituisci = "sostituisci_$ruolo_calc";
$formazione[$num2] = ereg_replace("
","",$formazione[$num2]);
$formazione[$num2] .= ",".$voto_tot[$num_calciatore]."
";
if ($$nome_sostituisci >= 1) {
$nome_calc = $dati_calciatore[1];
$formazione[$num2] = ereg_replace("$nome_calc","<b>$nome_calc</b>",$formazione[$num2]);
$punti_tot[$giocatore] = $punti_tot[$giocatore] + $voto_tot[$num_calciatore];
$$nome_sostituisci = $$nome_sostituisci - 1;
} # fine if ($$nome_sostituisci >= 1)
} # fine if ($voto_tot[$num_calciatore] != 0 or...
} # fine for $num2

# riscrivo la formazione con i voti
$lock = fopen("adnin.lock","w+");
flock($lock,2);
$fileformazione = fopen("$giornata/formazione_$giocatore","w+");
flock($fileformazione,2);
rewind($fileformazione);
for ($num2 = 0 ; $num2 < $num_linee_formazione ; $num2++) {
fwrite($fileformazione,$formazione[$num2]);
} # fine for $num1
flock($fileformazione,3);
flock($lock,3);
echo "$giocatore: ".$punti_tot[$giocatore]."<br>";
next($pass);
} # fine for $num1


$lock = fopen("adnin.lock","w+");
flock($lock,2);
$filepunteggi = fopen("$giornata/punteggi.txt","w+");
flock($filepunteggi,2);
rewind($filepunteggi);
reset($pass);
for($num1 = 0 ; $num1 < $num_giocatori; $num1++) {
$giocatore = key($pass);
fwrite($filepunteggi,"$giocatore,".$punti_tot[$giocatore]."
");
next($pass);
} # fine for $num1
flock($filepunteggi,3);
flock($lock,3);

echo "<form method=\"post\" action=\"giornata.php\">
<input type=\"hidden\" name=\"nome_utente\" value=\"$nome_utente\">
<input type=\"hidden\" name=\"pass_fornita\" value=\"$pass_fornita\">
<input type=\"hidden\" name=\"giornata\" value=\"$giornata\">
<input type=\"submit\" name=\"torna\" value=\"Torna indietro\">
</form>";

} # fine if ($pass_admin_errata == "NO")

include("foot.php");
?>
